<?php

namespace Slimco\Slimco\Policies;

use Litepie\User\Contracts\UserPolicy;
use Slimco\Slimco\Models\Slimco;

class SlimcoPolicy
{

    /**
     * Determine if the given user can view the slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function view(UserPolicy $user, Slimco $slimco)
    {
        if ($user->canDo('slimco.slimco.view') && $user->isAdmin()) {
            return true;
        }

        return $slimco->user_id == user_id() && $slimco->user_type == user_type();
    }

    /**
     * Determine if the given user can create a slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('slimco.slimco.create');
    }

    /**
     * Determine if the given user can update the given slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function update(UserPolicy $user, Slimco $slimco)
    {
        if ($user->canDo('slimco.slimco.edit') && $user->isAdmin()) {
            return true;
        }

        return $slimco->user_id == user_id() && $slimco->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Slimco $slimco)
    {
        return $slimco->user_id == user_id() && $slimco->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Slimco $slimco)
    {
        if ($user->canDo('slimco.slimco.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given slimco.
     *
     * @param UserPolicy $user
     * @param Slimco $slimco
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Slimco $slimco)
    {
        if ($user->canDo('slimco.slimco.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
