<?php

namespace Slimco\Slimco\Providers;

use Illuminate\Support\ServiceProvider;

class SlimcoServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'slimco');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'slimco');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('slimco.slimco', function ($app) {
            return $this->app->make('Slimco\Slimco\Slimco');
        });

                // Bind Slimco to repository
        $this->app->bind(
            'Slimco\Slimco\Interfaces\SlimcoRepositoryInterface',
            \Slimco\Slimco\Repositories\Eloquent\SlimcoRepository::class
        );

        $this->app->register(\Slimco\Slimco\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Slimco\Slimco\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['slimco.slimco'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('slimco/slimco.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/slimco')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/slimco')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
